==> nextcloud-23.0.5.tgz: nextcloud/apps/user_status/l10n/it.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Stati recenti",
    "In a meeting" : "In una riunione",
    "Commuting" : "Pendolare",
    "Out sick" : "In malattia",
    "Vacationing" : "In vacanza",
    "Working remotely" : "Lavoro da remoto",
    "In a call" : "In una chiamata",
    "User status" : "Stato utente",
    "View profile" : "Vedi profilo",
    "Clear status message after" : "Cancella il messaggio di stato dopo",
    "What is your status?" : "Qual è il tuo stato?",
    "Set status" : "Imposta stato",
    "Online status" : "Stato in linea",
    "Status message" : "Messaggio di stato",
    "Clear status message" : "Cancella il messaggio di stato",
    "Set status message" : "Imposta messaggio di stato",
    "There was an error saving the status" : "Si è verificato un errore durante il salvataggio dello stato",
    "There was an error clearing the status" : "Si è verificato un errore durante la rimozione dello stato",
    "No recent status changes" : "Nessun cambio di stato recente",
    "Away" : "Assente",
    "Do not disturb" : "Non disturbare",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Non togliere",
    "Today" : "Oggi",
    "This week" : "Questa settimana",
    "Online" : "In linea",
    "Invisible" : "Invisibile",
    "Offline" : "Non in linea",
    "There was an error saving the new status" : "Si è verificato un errore durante il salvataggio del nuovo stato",
    "30 minutes" : "30 minuti",
    "1 hour" : "1 ora",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Silenzia tutte le notifiche",
    "Appear offline" : "Mostrati non in linea",
    "What's your status?" : "Qual è il tuo stato?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p1.tgz: nextcloud/apps/user_status/l10n/it.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Stati recenti",
    "In a meeting" : "In una riunione",
    "Commuting" : "Pendolare",
    "Out sick" : "In malattia",
    "Vacationing" : "In vacanza",
    "Working remotely" : "Lavoro da remoto",
    "In a call" : "In una chiamata",
    "User status" : "Stato utente",
    "View profile" : "Vedi profilo",
    "Clear status after" : "Togli lo stato dopo",
    "What is your status?" : "Qual è il tuo stato?",
    "Set status" : "Imposta stato",
    "Online status" : "Stato in linea",
    "Status message" : "Messaggio di stato",
    "Clear status message" : "Cancella il messaggio di stato",
    "Set status message" : "Imposta messaggio di stato",
    "There was an error saving the status" : "Si è verificato un errore durante il salvataggio dello stato",
    "There was an error clearing the status" : "Si è verificato un errore durante la rimozione dello stato",
    "No recent status changes" : "Nessun cambio di stato recente",
    "Away" : "Assente",
    "Do not disturb" : "Non disturbare",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Non togliere",
    "Today" : "Oggi",
    "This week" : "Questa settimana",
    "Online" : "In linea",
    "Invisible" : "Invisibile",
    "Offline" : "Non in linea",
    "There was an error saving the new status" : "Si è verificato un errore durante il salvataggio del nuovo stato",
    "30 minutes" : "30 minuti",
    "1 hour" : "1 ora",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Silenzia tutte le notifiche",
    "Appear offline" : "Mostrati non in linea",
    "Clear status message after" : "Cancella il messaggio di stato dopo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
